==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebCancelableEventArgsDetail", () => new WebCancelableEventArgsDetailDescription());
            a.ac("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebCancelableEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebCancelableEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebCancelableEventArgsDetail", () => new WebCancelableEventArgsDetailDescription());
            a.ad("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
})();
